#!/bin/bash

parser_location=`cat $(dirname $0)/../data/location.txt | grep grc_parser | cut -f 2`

parse_and_check() {
	$parser_location $1
	if [ "$?" != 0 ]; then
		echo "Parsing $1 failed"
	fi
}

create_parsed_file() {
	local filename=$1
	local scripts_dir=$2
	local parsed_folder=$3

	#run dos2unix on the file
	dos2unix $filename 2> /dev/null
	if [ "$?" != "0" ]; then
		echo "dos2unix not found. Assuming output has linux line ending."
		echo "If the parse fails please install dos2unix."
	fi

	found=`grep Offset $filename -m 1 -oh`
	if [ "$found" == "Offset" ]; then
		# remove first two lines from ethtool and the address column
		cat $filename | sed -e "s/:[ \t]*/:/" | cut -d":" -f 2- | tail -n +3 2> /dev/null > $parsed_folder/temp
	else
		# turn binary dump into ethtool-like format
		hexdump -vC $filename | awk '{print substr($0,11)}' | sed -e 's/.\{20\}$//g' | tr -s ' ' > $parsed_folder/temp
	fi
		
	# call the parsing tool
	output=`$scripts_dir/internal/ethtool-d $parsed_folder/temp $parsed_folder`

	#remove the temp file
	rm -rf $parsed_folder/temp
}

# check if filename was entered
if [[ $# != 1 && $# != 2 ]]
then
	echo "Usage example:"
	echo "./ethtool-d.sh <filename> [-p (for parsing grcDump files)]"
	exit 1
fi
filename=$1
parse_option=$2

# check if the file exist
if [ -f $filename ]; then
	# check if the file is given in relative path or full path
	if [ `echo "$filename" | grep -c "/"` -gt 0 ] ; then
		path=${filename%/*}
	else
		path=`pwd`
	fi

	path+="/`basename $filename`_parsed"
	mkdir -p $path

	# create file
	create_parsed_file $filename $(dirname $0) $path

	echo "$output"
      	result=`echo $output | cut -d " " -f1`
	if [ "$result" != 'Success!' ]; then
		echo "Parsing failed!"
		exit
    	else
       	# get the number of grc_dump files that were created for parsing
       	num_of_grc_files=`echo $output | cut -d " " -f2`
	fi
	echo "The files were created in $path"
else
	echo "Failed to create parsed file, check the filename or path"
	exit 1
fi

#check if user wants to parse GrcDump
if [ "$parse_option" == "-p" ] ; then
	if [ "$num_of_grc_files" == "1" ]; then
		parse_and_check $path/GrcDump0.bin
		parse_and_check $path/IdleChk0.txt
		parse_and_check $path/IdleChk1.txt
		parse_and_check $path/FwAsserts0.txt
	else		 
		for i in `seq 0 $((num_of_grc_files - 1))`
        	do
			parse_and_check $path/GrcDump$i-engine$i.bin
			parse_and_check $path/IdleChk$((2*i))-engine$i.txt
			parse_and_check $path/IdleChk$((2*i+1))-engine$i.txt
			parse_and_check $path/FwAsserts$i-engine$i.txt
	        done
    	fi
fi

exit 0
