# synopsis
if [ "$#" != "1" ]
then
        echo "usage:	grc_analyzer.sh [grc dump text file]"
        echo "example:	grc_analyzer.sh GrcDump.txt "
        exit 1
fi

# params
grc_txt=$1
xsltfile=`dirname $0`/GrcAnalyzer/GRCAHtmlViewer.xslt

# sanity on input
if [[ `head -n 2 $grc_txt | grep -m 1 "dump-type: grc-dump"` ]]
then
	echo "Sending dump to Agent1 for analysis..."
else
	echo "input file is not a text grc dump, skipping"
	exit 0
fi

# connectivity to lb-tlvb-agent1.il.qlogic.org
ping lb-tlvb-agent1.il.qlogic.org -c1 &> /dev/null
if [ "$?" != "0" ]
then
	echo "cannot reach agent1"
	exit 1
fi

outbase="${grc_txt%.*}"
xmlfile=$outbase.xml
htmlfile=$outbase.html

# get analysis xml frmo agent1
curl -X POST -F 'params=-f -t raw -p 0 1 -w auto -m auto' -F 'grcdmp_file=@'${grc_txt}';type=text/plain' http://lb-tlvb-agent1.il.qlogic.org/GrcAnalyzer-Official\(Z:\)/GrcAnalyzer.run > $xmlfile
if [ "$?" != "0" ]
then
	echo "curl failed"
	exit 1
else
	echo created $xmlfile
fi

# convert to html with xslt
xsltproc $xsltfile  $xmlfile  > $htmlfile 2> /dev/null
if [ "$?" != "0" ]
then
	echo "xslt failed"
	exit 1
else
	echo created $htmlfile
fi


